@@ -7,6 +7,9 @@
 #' check_wkt('POINT(30.1 10.1)')
 #' check_wkt('LINESTRING(3 4,10 50,20 25)')
 #'
+#' # check many passed in at once
+#' check_wkt(c('POLYGON((30.1 10.1, 10 20, 20 60, 60 60, 30.1 10.1))', 'POINT(30.1 10.1)'))
+#'
 #' # this passes this check, but isn't valid for GBIF
 #' wkt <- 'POLYGON((-178.59375 64.83258989321493,-165.9375 59.24622380205539,
 #' -147.3046875 59.065977905449806,-130.78125 51.04484764446178,-125.859375 36.70806354647625,
@@ -24,13 +27,17 @@ check_wkt <- function(wkt = NULL){
   if (!is.null(wkt)) {
     stopifnot(is.character(wkt))
     y <- strextract(wkt, "[A-Z]+")
-    if (!y %in% c('POINT', 'POLYGON', 'LINESTRING', 'LINEARRING')) {
-      stop("WKT must be of type POINT, POLYGON, LINESTRING, or LINEARRING")
-    }
-    res <- tryCatch(read_wkt(wkt), error = function(e) e)
-    if (!is(res, 'list')) {
-      stop(res$message, call. = FALSE)
+
+    for (i in seq_along(wkt)) {
+      if (!y[i] %in% c('POINT', 'POLYGON', 'LINESTRING', 'LINEARRING')) {
+        stop("WKT must be of type POINT, POLYGON, LINESTRING, or LINEARRING", call. = FALSE)
+      }
+      res <- tryCatch(read_wkt(wkt[i]), error = function(e) e)
+      if (!is(res, 'list')) {
+        stop(res$message, call. = FALSE)
+      }
     }
+
     return(wkt)
   } else {
     NULL
