@@ -72,13 +72,13 @@ elevation <- function(input=NULL, latitude=NULL, longitude=NULL, latlong=NULL, k
       tt <- GET(url, query = args, make_rgbif_ua(), ...)
       stop_for_status(tt)
       stopifnot(tt$headers$`content-type` == 'application/json; charset=UTF-8')
-      res <- content(tt, as = 'text', encoding = "UTF-8")
+      res <- c_utf8(tt)
       out <- jsonlite::fromJSON(res, FALSE)
 
       df <- data.frame(elevation = sapply(out$results, '[[', 'elevation'), stringsAsFactors = FALSE)
       outout[[i]] <- df
     }
-    datdf <- data.frame(rbindlist(outout), stringsAsFactors = FALSE)
+    datdf <- setDF(rbindlist(outout))
     return( cbind(x, datdf) )
   }
 
@@ -94,9 +94,9 @@ elevation <- function(input=NULL, latitude=NULL, longitude=NULL, latlong=NULL, k
     dat <- data.frame(latitude = latitude, longitude = longitude, stringsAsFactors = FALSE)
     getdata(dat)
   } else {
-    dat <- data.frame(rbindlist(
+    dat <- setDF(rbindlist(
       lapply(latlong, function(x) data.frame(t(x)))
-    ), stringsAsFactors = FALSE)
+    ))
     names(dat) <- c("latitude","longitude")
     getdata(dat)
   }
